@@ -149,12 +149,40 @@ void Chart::setIndexingMode(IndexingMode newIndexingMode)
     Q_EMIT indexingModeChanged();
 }
 
+int Chart::highlight() const
+{
+    return m_highlight;
+}
+
+void Chart::setHighlight(int newHighlight)
+{
+    if (newHighlight == m_highlight) {
+        return;
+    }
+
+    m_highlight = newHighlight;
+    Q_EMIT dataChanged();
+    Q_EMIT highlightChanged();
+}
+
+void Chart::resetHighlight()
+{
+    setHighlight(-1);
+}
+
 void Chart::componentComplete()
 {
     QQuickItem::componentComplete();
     Q_EMIT dataChanged();
 }
 
+QColor Chart::desaturate(const QColor &input)
+{
+    auto color = input.convertTo(QColor::Hsl);
+    color.setHslF(color.hueF(), color.saturationF() * 0.5, color.lightnessF() * 0.5, color.alphaF() * 0.5);
+    return color.convertTo(QColor::Rgb);
+}
+
 void Chart::appendSource(Chart::DataSourcesProperty *list, ChartDataSource *source)
 {
     auto chart = reinterpret_cast<Chart *>(list->data);
